@@ -14,7 +14,7 @@ def frame_data_path():
 
 
 def test_register_plugins_called(mocker, frame_data_path):
-    mock_register = mocker.patch("compas_pb.core._discover_serializers")
+    mock_register = mocker.patch("compas_pb.core._ensure_serializers")
     data = pb_load(frame_data_path)
 
     # register_serializers should be called at least once during deserialization
@@ -26,7 +26,7 @@ def test_register_plugins_called(mocker, frame_data_path):
 
 def test_pb_dump_and_load_equivalence(mocker):
     """Test that pb_dump and pb_load work correctly together."""
-    mock_register = mocker.patch("compas_pb.core._discover_serializers")
+    mock_register = mocker.patch("compas_pb.core._ensure_serializers")
 
     with tempfile.TemporaryDirectory() as tmpdir:
         tmp_path = Path(tmpdir) / "frame_out.data"
